==> gwt-bean-validators-engine-gwt-user-1.8.7.jar: de/knightsoftnet/validators/gwtuser/supersource/com/google/gwt/validation/client/impl/ConstraintViolationImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.gwt.validation.client.impl;

import java.lang.annotation.ElementType;

import javax.validation.Path;
import javax.validation.metadata.ConstraintDescriptor;

/**
 * Dummy to fix compile problems as long validation-api 1.0 implementation is part of gwt.
 *
 * @author Manfred Tremmel
 *
 */
public class ConstraintViolationImpl<T>
    extends de.knightsoftnet.validators.client.impl.ConstraintViolationImpl<T> {

  private static final long serialVersionUID = 4457071990894400119L;

  protected ConstraintViolationImpl(final String pmessage, final String pmessageTemplate,
      final T prootBean, final Class<T> prootBeanClass, final Object pleafBean,
      final Path ppropertyPath, final Object pinvalidValue, final ElementType pelementType,
      final ConstraintDescriptor<?> pconstraintDescriptor) {
    super(pmessage, pmessageTemplate, prootBean, prootBeanClass, pleafBean, ppropertyPath,
        pinvalidValue, pelementType, pconstraintDescriptor);
  }
}

==> gwt-bean-validators-engine-gwt-user-2.1.3.jar: de/knightsoftnet/validators/gwtuser/supersource/com/google/gwt/validation/client/impl/ConstraintViolationImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.gwt.validation.client.impl;

import java.lang.annotation.ElementType;

import jakarta.validation.Path;
import jakarta.validation.metadata.ConstraintDescriptor;

/**
 * Dummy to fix compile problems as long validation-api 1.0 implementation is part of gwt.
 *
 * @author Manfred Tremmel
 *
 */
public class ConstraintViolationImpl<T>
    extends de.knightsoftnet.validators.client.impl.ConstraintViolationImpl<T> {

  private static final long serialVersionUID = 4457071990894400119L;

  protected ConstraintViolationImpl(final String pmessage, final String pmessageTemplate,
      final T prootBean, final Class<T> prootBeanClass, final Object pleafBean,
      final Path ppropertyPath, final Object pinvalidValue, final ElementType pelementType,
      final ConstraintDescriptor<?> pconstraintDescriptor) {
    super(pmessage, pmessageTemplate, prootBean, prootBeanClass, pleafBean, ppropertyPath,
        pinvalidValue, pelementType, pconstraintDescriptor);
  }
}
